==> ark-15.08.0.tar.xz: ark-15.08.0/plugins/clirarplugin/kerfuffle_clirar.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=Kerfuffle/Plugin
X-KDE-Library=kerfuffle_clirar
X-KDE-PluginInfo-Author=Harald Hvaal
X-KDE-PluginInfo-Email=haraldhv@stud.ntnu.no
X-KDE-PluginInfo-Name=kerfuffle_clirar
X-KDE-PluginInfo-Version=0.0.1
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-License=GPLv2+
X-KDE-Priority=120
X-KDE-Kerfuffle-APIRevision=1
X-KDE-Kerfuffle-ReadWrite=true
X-KDE-Kerfuffle-EncryptEntries=true
X-KDE-Kerfuffle-EncryptHeader=true
Name=RAR archive plugin
Name[ar]=ملحق أرشيف RAR
Name[ast]=Complementu d'archivos RAR
Name[bg]=Приставка за архиви RAR
Name[bs]=Priključak RAR arhiva
Name[ca]=Connector per arxius RAR
Name[ca@valencia]=Connector per arxius RAR
Name[cs]=Modul pro archiv RAR
Name[da]=Plugin til RAR-arkiver
Name[de]=RAR-Archiv-Modul
Name[el]=πρόσθετο αρχειοθήκης RAR
Name[en_GB]=RAR archive plugin
Name[es]=Complemento de archivo comprimido RAR
Name[et]=RAR-arhiivi plugin
Name[eu]=RAR artxiboen plugina
Name[fi]=RAR-pakkaustuki
Name[fr]=Module externe d'archive « RAR »
Name[ga]=Breiseán cartlainne RAR
Name[gl]=Extensión de arquivo RAR
Name[hr]=Arhivni priključak RAR
Name[hu]=RAR modul
Name[ia]=plugin de archivar RAR
Name[id]=Pengaya arsip RAR
Name[it]=estensione per archivi RAR
Name[ja]=RAR アーカイブ用プラグイン
Name[kk]=RAR архив плагині
Name[km]=កម្មវិធី​ជំនួយ​ប័ណ្ណសារ RAR
Name[ko]=RAR 압축 플러그인
Name[lt]=RAR archyvo priedas
Name[lv]=RAR arhīvu spraudnis
Name[mr]=RAR संग्रह प्लगइन
Name[nb]=Programtillegg for RAR-arkiv
Name[nds]=RAR-Archievmoduul
Name[nl]=RAR-archiefplug-in
Name[nn]=RAR-arkivtillegg
Name[pa]=RAR ਅਕਾਇਵ ਪਲੱਗਇਨ
Name[pl]=Wtyczka archiwów RAR
Name[pt]='Plugin' de pacotes RAR
Name[pt_BR]=Plugin de arquivos RAR
Name[ro]=Modul de arhivă RAR
Name[ru]=Поддержка архивов RAR
Name[sk]=Modul RAR archívu
Name[sl]=Vstavek za arhive RAR
Name[sq]=RAR arkiv plugin
Name[sr]=Прикључак РАР архива
Name[sr@ijekavian]=Прикључак РАР архива
Name[sr@ijekavianlatin]=Priključak RAR arhiva
Name[sr@latin]=Priključak RAR arhiva
Name[sv]=Insticksprogram för RAR-arkiv
Name[th]=ส่วนเสริมการจัดการแฟ้มจัดเก็บบีบอัดแบบ RAR
Name[tr]=RAR arşivi eklentisi
Name[uk]=Додаток для архівів RAR
Name[x-test]=xxRAR archive pluginxx
Name[zh_CN]=RAR 归档插件
Name[zh_TW]=RAR 壓縮檔外掛程式
MimeType=@SUPPORTED_CLIRAR_MIMETYPES@

==> ark-15.11.80.tar.xz: ark-15.11.80/plugins/clirarplugin/kerfuffle_clirar.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=Kerfuffle/Plugin
X-KDE-Library=kerfuffle_clirar
X-KDE-PluginInfo-Author=Harald Hvaal
X-KDE-PluginInfo-Email=haraldhv@stud.ntnu.no
X-KDE-PluginInfo-Name=kerfuffle_clirar
X-KDE-PluginInfo-Version=0.0.1
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-License=GPLv2+
X-KDE-Priority=120
X-KDE-Kerfuffle-APIRevision=1
X-KDE-Kerfuffle-ReadWrite=true
X-KDE-Kerfuffle-EncryptEntries=@ENCRYPT_ENTRIES_MIMETYPES@
X-KDE-Kerfuffle-EncryptHeader=@ENCRYPT_HEADER_MIMETYPES@
Name=RAR archive plugin
Name[ar]=ملحق أرشيف RAR
Name[ast]=Complementu d'archivos RAR
Name[bg]=Приставка за архиви RAR
Name[bs]=Priključak RAR arhiva
Name[ca]=Connector per arxius RAR
Name[ca@valencia]=Connector per arxius RAR
Name[cs]=Modul pro archiv RAR
Name[da]=Plugin til RAR-arkiver
Name[de]=RAR-Archiv-Modul
Name[el]=πρόσθετο αρχειοθήκης RAR
Name[en_GB]=RAR archive plugin
Name[es]=Complemento de archivo comprimido RAR
Name[et]=RAR-arhiivi plugin
Name[eu]=RAR artxiboen plugina
Name[fi]=RAR-pakkaustuki
Name[fr]=Module externe d'archive « RAR »
Name[ga]=Breiseán cartlainne RAR
Name[gl]=Extensión de arquivo RAR
Name[hr]=Arhivni priključak RAR
Name[hu]=RAR modul
Name[ia]=plugin de archivar RAR
Name[id]=Pengaya arsip RAR
Name[it]=estensione per archivi RAR
Name[ja]=RAR アーカイブ用プラグイン
Name[kk]=RAR архив плагині
Name[km]=កម្មវិធី​ជំនួយ​ប័ណ្ណសារ RAR
Name[ko]=RAR 압축 플러그인
Name[lt]=RAR archyvo priedas
Name[lv]=RAR arhīvu spraudnis
Name[mr]=RAR संग्रह प्लगइन
Name[nb]=Programtillegg for RAR-arkiv
Name[nds]=RAR-Archievmoduul
Name[nl]=RAR-archiefplug-in
Name[nn]=RAR-arkivtillegg
Name[pa]=RAR ਅਕਾਇਵ ਪਲੱਗਇਨ
Name[pl]=Wtyczka archiwów RAR
Name[pt]='Plugin' de pacotes RAR
Name[pt_BR]=Plugin de arquivos RAR
Name[ro]=Modul de arhivă RAR
Name[ru]=Поддержка архивов RAR
Name[sk]=Modul RAR archívu
Name[sl]=Vstavek za arhive RAR
Name[sq]=RAR arkiv plugin
Name[sr]=Прикључак РАР архива
Name[sr@ijekavian]=Прикључак РАР архива
Name[sr@ijekavianlatin]=Priključak RAR arhiva
Name[sr@latin]=Priključak RAR arhiva
Name[sv]=Insticksprogram för RAR-arkiv
Name[th]=ส่วนเสริมการจัดการแฟ้มจัดเก็บบีบอัดแบบ RAR
Name[tr]=RAR arşivi eklentisi
Name[uk]=Додаток для архівів RAR
Name[x-test]=xxRAR archive pluginxx
Name[zh_CN]=RAR 归档插件
Name[zh_TW]=RAR 壓縮檔外掛程式
MimeType=@SUPPORTED_CLIRAR_MIMETYPES@
